inline int DateTime::displayZoneShift() const
{
    return d_zone / 60;
}
